package com.muyu.common.system.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.TreeEntity;
import com.muyu.common.system.domain.req.SysDistrictEditReq;
import com.muyu.common.system.domain.req.SysDistrictQueryReq;
import com.muyu.common.system.domain.req.SysDistrictSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;

/**
 * 地域地区对象 sys_district
 *
 * @author DongZeLiang
 * @date 2024-04-11
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("sys_district")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "SysDistrict", description = "地域地区")
public class SysDistrict extends TreeEntity {

    private static final long serialVersionUID = 1L;

    /** ID */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "ID", value = "ID")
    private Long id;

    /** 名称 */
    @Excel(name = "名称")
    @ApiModelProperty(name = "名称", value = "名称")
    private String name;

    /** 编码 */
    @Excel(name = "编码")
    @ApiModelProperty(name = "编码", value = "编码")
    private String code;

    /** 级别 */
    @Excel(name = "级别")
    @ApiModelProperty(name = "级别", value = "级别")
    private String level;

    /** 级别编码 */
    @ApiModelProperty(name = "级别编码", value = "级别编码")
    private String codeLevel;

    /** 区域编码 */
    @Excel(name = "区域编码")
    @ApiModelProperty(name = "区域编码", value = "区域编码")
    private String areaCode;

    /** 中心经纬度 */
    @Excel(name = "中心经纬度")
    @ApiModelProperty(name = "中心经纬度", value = "中心经纬度")
    private String center;

    /**
    * 查询构造器
    */
    public static SysDistrict queryBuild( SysDistrictQueryReq sysDistrictQueryReq){
        return SysDistrict.builder()
                .parentId(sysDistrictQueryReq.getParentId())
                .name(sysDistrictQueryReq.getName())
                .code(sysDistrictQueryReq.getCode())
                .level(sysDistrictQueryReq.getLevel())
                .areaCode(sysDistrictQueryReq.getAreaCode())
                .build();
    }

    /**
    * 添加构造器
    */
    public static SysDistrict saveBuild(SysDistrictSaveReq sysDistrictSaveReq){
        return SysDistrict.builder()
                .parentId(sysDistrictSaveReq.getParentId())
                .name(sysDistrictSaveReq.getName())
                .code(sysDistrictSaveReq.getCode())
                .level(sysDistrictSaveReq.getLevel())
                .codeLevel(sysDistrictSaveReq.getCodeLevel())
                .areaCode(sysDistrictSaveReq.getAreaCode())
                .center(sysDistrictSaveReq.getCenter())
                .build();
    }

    /**
    * 修改构造器
    */
    public static SysDistrict editBuild(Long id, SysDistrictEditReq sysDistrictEditReq){
        return SysDistrict.builder()
            .id(id)
                .parentId(sysDistrictEditReq.getParentId())
                .name(sysDistrictEditReq.getName())
                .code(sysDistrictEditReq.getCode())
                .level(sysDistrictEditReq.getLevel())
                .codeLevel(sysDistrictEditReq.getCodeLevel())
                .areaCode(sysDistrictEditReq.getAreaCode())
                .center(sysDistrictEditReq.getCenter())
                .build();
    }

}
