package com.muyu.marketing.domain.model;


import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.marketing.domain.req.ActivityTeamInfoSaveReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * 团购活动添加模型
 *
 * @author DongZeLiang
 * @date 2024-11-26 09:38
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ActivityTeamInfoAddModel {

    /**
     * 拼团名称
     */
    private String name;
    /**
     * 商品ID
     */
    private Long productId;
    /**
     * 商品活动图
     */
    private String productImage;
    /**
     * 活动简介
     */
    private String introduction;
    /**
     * 单位
     */

    private String unit;
    /**
     * 轮播图
     */

    private String imageList;
    /**
     * 活动结束时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private Date endTime;
    /**
     * 活动排序
     */
    private Long sort;
    /**
     * 商品SkU集合
     */
    private List<ActivityTeamProductSkuAddModel> activityTeamProductSkuAddModelList;
    /**
     * 活动详情
     */
    private String content;
    /**
     * 活动状态
     */
    private String status;
    /**
     * 策略类型
     */
    private String strategyType;
    /**
     * 策略ID
     */
    private Long strategyId;

    public static ActivityTeamInfoAddModel addReqBuild (ActivityTeamInfoSaveReq activityTeamInfoSaveReq){
        return ActivityTeamInfoAddModel.builder()
                .name(activityTeamInfoSaveReq.getName())
                .productId(activityTeamInfoSaveReq.getProductId())
                .productImage(activityTeamInfoSaveReq.getProductImage())
                .introduction(activityTeamInfoSaveReq.getIntroduction())
                .unit(activityTeamInfoSaveReq.getUnit())
                .imageList(activityTeamInfoSaveReq.getImageList())
                .endTime(activityTeamInfoSaveReq.getEndTime())
                .sort(activityTeamInfoSaveReq.getSort())
                .content(activityTeamInfoSaveReq.getContent())
                .status(activityTeamInfoSaveReq.getStatus())
                .strategyType(activityTeamInfoSaveReq.getStrategyType())
                .strategyId(activityTeamInfoSaveReq.getStrategyId())
                .activityTeamProductSkuAddModelList(
                        activityTeamInfoSaveReq.getTeamProjectSkuInfoAddReqList()
                                .stream()
                                .map(addReq -> ActivityTeamProductSkuAddModel.addReqBuild(addReq, activityTeamInfoSaveReq::getProductId))
                                .toList()
                ).build();
    }
}
