package com.muyu.marketing.domain.model;


import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.math.RoundingMode;

/**
 * 团购商品优惠力度模型
 *
 * @author DongZeLiang
 * @date 2024-11-21 11:57
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class TeamProductDiscountPriceModel {

    /**
     * 商品价格
     */
    private BigDecimal productPrice;

    /**
     * 团购优惠价格
     */
    private BigDecimal teamPrice;


    /**
     * 优惠力度 （商品价格 - 团购优惠价格） / 商品价格
     */
    private double discount;

    /**
     * 通过 商品价格和团购价格 生成优惠力度
     * @param productPrice 商品价格
     * @param teamPrice 团购加
     * @return 优惠力度
     */
    public static TeamProductDiscountPriceModel of(BigDecimal productPrice, BigDecimal teamPrice) {
        return TeamProductDiscountPriceModel.builder()
                .productPrice(productPrice)
                .teamPrice(teamPrice)
                .discount(
                        productPrice.subtract(teamPrice).divide(productPrice, 2, RoundingMode.HALF_UP).doubleValue()
                )
                .build();
    }
}
