package com.muyu.marketing.team.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.marketing.domain.ActivityTeamProductSkuInfo;
import com.muyu.marketing.domain.model.*;

import java.util.List;

public interface ActivityTeamProductSkuInfoService extends IService<ActivityTeamProductSkuInfo> {

    public default List<ActivityTeamProductSkuInfo> getActivityTeamProductSkuInfoByTeamId(Long teamId){
        LambdaQueryWrapper<ActivityTeamProductSkuInfo> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ActivityTeamProductSkuInfo::getTeamId, teamId);
        return this.list(lambdaQueryWrapper);
    }


    /**
     * 通过团购活动ID获取团购中最优惠的价格
     * @param teamId 团购ID
     * @return 优惠价格
     */
    public TeamProductDiscountPriceModel getDiscountPrice(Long teamId);


    /**
     * 通过活动ID获取 剩余库存
     * @param teamId 活动ID
     * @return 库存
     */
    public TeamProductStockModel getStock(Long teamId);


    /**
     * 添加团购商品SKU
     * @param activityTeamProductSkuAddModelList 团购商品SKU添加模型集合
     */
    public void batchSave(List<ActivityTeamProductSkuAddModel> activityTeamProductSkuAddModelList);

    /**
     * 通过拼团活动ID获取拼团下商品SKU集合
     * @param teamId 活动ID
     * @return 拼团商品SKU集合
     */
    public List<ActivityTeamProductSkuModel> findListByTeamId(Long teamId);

    public boolean updateBath(List<ActivityTeamProductSkuReqModel> activityTeamProductSkuReqModelList);

    /**
     * 根据 业务模型 进行 团购商品修改
     * @param activityTeamProductSkuUpdModel 修改业务模型
     * @return 修改结果
     */
    public boolean update(ActivityTeamProductSkuUpdModel activityTeamProductSkuUpdModel);

    /**
     * 根据 业务模型 进行 团购商品批量修改
     * @param activityTeamProductSkuUpdModelList 修改业务模型
     * @return 修改结果
     */
    public boolean batchUpdate(List<ActivityTeamProductSkuUpdModel> activityTeamProductSkuUpdModelList);

    /**
     * 一键设置
     * @param activityTeamProductSkuSettingModel 整体修改模型
     */
    public default void setting(ActivityTeamProductSkuSettingModel activityTeamProductSkuSettingModel){
        this.batchSave(activityTeamProductSkuSettingModel.getActivityTeamProductSkuAddModelList());
        this.batchUpdate(activityTeamProductSkuSettingModel.getActivityTeamProductSkuUpdModelList());
        this.removeByIds(activityTeamProductSkuSettingModel.getRemoveIds());
    }
}
