package com.muyu.marketing.team.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.marketing.domain.ActivityTeamInfo;
import com.muyu.marketing.domain.model.*;
import com.muyu.marketing.team.mapper.ActivityTeamInfoMapper;
import com.muyu.marketing.team.service.ActivityTeamInfoService;
import com.muyu.marketing.team.service.ActivityTeamOpenInfoService;
import com.muyu.marketing.team.service.ActivityTeamProductSkuInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.List;


@Service
public class ActivityTeamInfoServiceImpl extends ServiceImpl<ActivityTeamInfoMapper, ActivityTeamInfo>
    implements ActivityTeamInfoService {

    @Autowired
    private ActivityTeamOpenInfoService activityTeamOpenInfoService;

    @Autowired
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;

    @Override
    public TableDataInfo<ActivityTeamInfoListModel> query(ActivityTeamInfoListQueryModel activityTeamInfoListQueryModel) {

        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getKeyWord()), ActivityTeamInfo::getName, activityTeamInfoListQueryModel.getKeyWord());
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getStatus()), ActivityTeamInfo::getStatus, activityTeamInfoListQueryModel.getStatus());

        /**
         * Object<T> -> 创建对象的时候进行的占用
         * <T> Result<T> 以方法返回值为占用
         */
        Page<ActivityTeamInfo> activityTeamInfoPage = this.page(activityTeamInfoListQueryModel.buildPage(), queryWrapper);
        List<ActivityTeamInfo> activityTeamInfoList = activityTeamInfoPage.getRecords();
        List<ActivityTeamInfoListModel> activityTeamInfoListModels = activityTeamInfoList.stream()
                .map(activityTeamInfo -> ActivityTeamInfoListModel.infoBuild(activityTeamInfo,
                        (activityTeamInfoListModelBuilder) -> {
                            TeamProductDiscountPriceModel discountPrice = activityTeamProductSkuInfoService.getDiscountPrice(activityTeamInfo.getId());
                            TeamProductStockModel teamProductStockModel = activityTeamProductSkuInfoService.getStock(activityTeamInfo.getId());
                            Long teamOpenTypeNumber = activityTeamOpenInfoService.getTeamOpenTypeNumberByTeamId(activityTeamInfo.getId());
                            Long teamInTypeNumber = activityTeamOpenInfoService.getTeamInTypeNumberByTeamId(activityTeamInfo.getId());

                            return activityTeamInfoListModelBuilder
                                    .openTeamNumber(teamOpenTypeNumber)
                                    .addTeamNumber(teamInTypeNumber)
                                    .attendNumber(teamOpenTypeNumber + teamInTypeNumber)
                                    .teamPrice(discountPrice.getTeamPrice())
                                    .productPrice(discountPrice.getProductPrice())
                                    .teamStock(teamProductStockModel.getTeamStock())
                                    .remainStock(teamProductStockModel.getRemainStock())
                                    .build();
                        })).toList();
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = new TableDataInfo<>();
        tableDataInfo.setTotal(activityTeamInfoPage.getTotal());
        tableDataInfo.setRows(activityTeamInfoListModels);
        return tableDataInfo;
    }

    /**
     * 通过添加模型，去进行商品拼团活动的操作
     *
     * @param activityTeamInfoAddModel 团购添加模型
     */
    @Override
    public void save(ActivityTeamInfoAddModel activityTeamInfoAddModel) {
        ActivityTeamInfo activityTeamInfo = ActivityTeamInfo.addModelBuild(activityTeamInfoAddModel);
        Assert.isTrue(this.save(activityTeamInfo), StringUtils.format("团购活动添加失败：[{}]", activityTeamInfoAddModel));
        List<ActivityTeamProductSkuAddModel> teamProductSkuAddModelList = activityTeamInfoAddModel.getActivityTeamProductSkuAddModelList();
        teamProductSkuAddModelList.forEach(activityTeamProductSkuAddModel -> activityTeamProductSkuAddModel.setTeamId(activityTeamInfo.getId()));
        this.activityTeamProductSkuInfoService.batchSave(teamProductSkuAddModelList);
    }

    /**
     * 根据ID查询商品的详情
     * @param id 团购活动ID
     * @return 团购详情
     */
    @Override
    public ActivityTeamDetailModel findDetailById(Long id) {
        ActivityTeamInfo activityTeamInfo = this.getById(id);
        List<ActivityTeamProductSkuModel> activityTeamProductSkuModelList = activityTeamProductSkuInfoService.findListByTeamId(id);
        return ActivityTeamDetailModel.findSkuSumList(activityTeamInfo,
                (teamInfoFindByIdRespModelBuilder) -> teamInfoFindByIdRespModelBuilder.projectSkuInfoAddReqList(activityTeamProductSkuModelList).build()
        );
    }

    /**
     * 修改团购活动信息
     * @param activityTeamInfoUpdModel 团购活动信息
     * @return 是否成功
     */
    @Override
    public boolean update(ActivityTeamInfoUpdModel activityTeamInfoUpdModel) {
        boolean update = this.updateById(ActivityTeamInfo.TeamUpdateBuild(activityTeamInfoUpdModel));
        Assert.isTrue(update,"修改失败");
        activityTeamProductSkuInfoService.setting(activityTeamInfoUpdModel.getActivityTeamProductSkuSettingModel());
        return update;
    }
}
