package com.muyu.product.cache;

import com.muyu.common.cache.HashCache;
import com.muyu.common.cache.abs.CacheAbs;
import com.muyu.common.core.text.Convert;
import com.muyu.product.cache.datasource.ProjectInfoData;
import com.muyu.product.domain.ProjectInfo;
import com.muyu.product.domain.ProjectSkuInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;

/**
 * @author DongZl
 * @description: 商品缓存
 * @Date 2024-3-27 下午 03:30
 */
@Component
public class ProjectInfoCache extends CacheAbs<Long, ProjectInfo> {

    @Autowired
    private ProjectInfoData projectInfoData;

    /**
     * key前缀
     *
     * @return key前缀
     */
    @Override
    public String keyPre () {
        return "project:info:";
    }

    /**
     * 解码
     *
     * @param redisKey 数据库键
     *
     * @return ID
     */
    @Override
    public Long decode (String redisKey) {
        return Convert.toLong(redisKey.replace(keyPre(),""), 0L);
    }

    /**
     * 从数据库获取数据
     *
     * @param key ID
     *
     * @return 缓存对象
     */
    @Override
    public ProjectInfo getData (Long key) {
        return projectInfoData.getData(key);
    }

    /**
     * 默认值
     */
    @Override
    public ProjectInfo defaultValue () {
        return new ProjectInfo();
    }
}
