package com.muyu.product.cache;

import com.muyu.common.cache.abs.HashCacheAbs;
import com.muyu.common.core.text.Convert;
import com.muyu.product.cache.datasource.ProjectSkuData;
import com.muyu.product.domain.ProjectSkuInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

/**
 * @author DongZl
 * @description: 商品sku基本信息
 * @Date 2024-3-29 下午 03:06
 */
@Component
public class ProjectSkuCache extends HashCacheAbs<Long, String, ProjectSkuInfo> {

    @Autowired
    private ProjectSkuData projectSkuData;


    /**
     * key前缀
     * @return key前缀
     */
    @Override
    public String keyPre () {
        return "project:sku:";
    }

    /**
     * 解码
     * @param redisKey 数据库键
     * @return ID
     */
    @Override
    public Long decode (String redisKey) {
        return Convert.toLong(redisKey.replace(keyPre(), ""));
    }

    /**
     * 解码
     * @param redisHashKey 数据库键
     * @return ID
     */
    @Override
    public String decodeHashKey (String redisHashKey) {
        return redisHashKey;
    }

    /**
     * 通过键获取所有的hash数据
     * @param key 键
     * @return
     */
    @Override
    public Map<String, ProjectSkuInfo> getData (Long key) {
        return projectSkuData.getData(key);
    }

    /**
     * 通过缓存键和hash键获取hash值
     * @param key     缓存键
     * @param hashKey hash键
     *
     * @return hash值
     */
    @Override
    public ProjectSkuInfo getData (Long key, String hashKey) {
        return projectSkuData.getData(key, hashKey);
    }

    /**
     * 默认值
     */
    @Override
    public Map<String, ProjectSkuInfo> defaultValue () {
        return new HashMap<>();
    }

    @Override
    public ProjectSkuInfo defaultHashValue () {
        return new ProjectSkuInfo();
    }
}
