package com.muyu.product.cache;

import com.muyu.common.cache.abs.AtomicSequenceCacheAbs;
import com.muyu.common.core.text.Convert;
import com.muyu.product.cache.datasource.ProjectSkuStockData;
import com.muyu.product.cache.key.SkuStockKey;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author DongZl
 * @description: 商品SKU库存缓存
 * @Date 2024-3-29 下午 03:06
 */
@Service
public class ProjectSkuStockCache extends AtomicSequenceCacheAbs<SkuStockKey> {

    @Autowired
    private ProjectSkuStockData projectSkuStockData;

    /**
     * key前缀
     *
     * @return key前缀
     */
    @Override
    public String keyPre () {
        return "project:sku:stock:";
    }


    /**
     * 编码
     * @param skuStockKey ID
     * @return 键
     */
    @Override
    public String encode (SkuStockKey skuStockKey) {
        return keyPre() + skuStockKey.getProjectId() + ":" + skuStockKey.getSku();
    }

    @Override
    public Long getData (SkuStockKey key) {
        return projectSkuStockData.getData(key);
    }

    /**
     * 解码
     * @param redisKey 数据库键
     * @return ID
     */
    @Override
    public SkuStockKey decode (String redisKey) {
        String[] split = redisKey.replace(keyPre(), "").split(":");
        return SkuStockKey.builder()
                .projectId(Convert.toLong(split[0]))
                .sku(split[1])
                .build();
    }

}
