package com.muyu.product.cache;

import com.muyu.common.cache.abs.CacheAbs;
import com.muyu.common.core.text.Convert;
import com.muyu.product.cache.datasource.RuleCacheData;
import com.muyu.product.cache.model.RuleCacheModel;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * @author DongZl
 * @description: 规格缓存
 * @Date 2024/4/7 下午8:29
 */
public class RuleInfoCache extends CacheAbs<Long, RuleCacheModel> {

    @Autowired
    private RuleCacheData ruleCacheData;

    /**
     * key前缀
     *
     * @return key前缀
     */
    @Override
    public String keyPre () {
        return "rule:info:";
    }

    /**
     * 解码
     * @param redisKey 数据库键
     * @return ID
     */
    @Override
    public Long decode (String redisKey) {
        return Convert.toLong(redisKey.replace(keyPre(), ""));
    }


    /**
     * 从数据库获取数据
     *
     * @param key ID
     *
     * @return 缓存对象
     */
    @Override
    public RuleCacheModel getData (Long key) {
        return ruleCacheData.getRuleCacheModel(key);
    }

    /**
     * 默认值
     */
    @Override
    public RuleCacheModel defaultValue () {
        return new RuleCacheModel();
    }

}
