package com.muyu.product.cache.datasource.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.core.domain.Result;
import com.muyu.product.cache.datasource.ProjectSkuData;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.product.remote.RemoteProjectSkuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author DongZl
 * @description: 商品SKU实现类
 * @Date 2024-4-1 上午 11:38
 */
@Service
public class ProjectSkuDataRemoteImpl implements ProjectSkuData {

    @Autowired
    private RemoteProjectSkuService remoteProjectSkuService;

    /**
     * 通过键获取所有的hash数据
     * @param projectId 商品ID
     * @return
     */
    @Override
    public Map<String, ProjectSkuInfo> getData (Long projectId) {
        Result<List<ProjectSkuInfo>> projectListResult
                = remoteProjectSkuService.listByProjectId(projectId);
        if (Result.isError(projectListResult)){
            return new HashMap<>();
        }

        List<ProjectSkuInfo> projectSkuInfoList = projectListResult.getData();
        return projectSkuInfoList.stream()
                .collect(Collectors.toMap(ProjectSkuInfo::getSku, projectSkuInfo -> projectSkuInfo));

    }

    /**
     * 通过缓存键和hash键获取hash值
     * @param projectId  商品ID
     * @param projectSku 商品SKU
     * @return hash值
     */
    @Override
    public ProjectSkuInfo getData (Long projectId, String projectSku) {
        Result<ProjectSkuInfo> projectSkuInfoResult = remoteProjectSkuService.getInfoByProjectIdAndSku(
                projectId, projectSku
        );
        if (Result.isError(projectSkuInfoResult)){
            return new ProjectSkuInfo();
        }
        return projectSkuInfoResult.getData();
    }
}
