package com.muyu.product.cache.datasource.impl;

import com.muyu.common.core.domain.Result;
import com.muyu.product.cache.datasource.RuleCacheData;
import com.muyu.product.cache.model.RuleAttrCacheModel;
import com.muyu.product.cache.model.RuleCacheModel;
import com.muyu.product.domain.RuleAttrInfo;
import com.muyu.product.domain.RuleInfo;
import com.muyu.product.remote.RemoteRuleAttrService;
import com.muyu.product.remote.RemoteRuleService;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;

/**
 * @author DongZl
 * @description: 规格数据获取实现层 默认就读取远程调用
 * @Date 2024/4/7 下午8:32
 */
public class RuleCacheDataRemoteImpl implements RuleCacheData {

    @Autowired
    private RemoteRuleService remoteRuleService;

    @Autowired
    private RemoteRuleAttrService remoteRuleAttrService;

    @Override
    public RuleCacheModel getRuleCacheModel (Long ruleId) {
        Result<RuleInfo> ruleInfoResult = remoteRuleService.getInfo(ruleId);
        Result<List<RuleAttrInfo>> ruleAttrResult = remoteRuleAttrService.getInfoByRuleId(ruleId);
        if (Result.isError(ruleInfoResult) || Result.isError(ruleAttrResult)) {
            return new RuleCacheModel();
        }
        RuleInfo ruleInfo = ruleInfoResult.getData();
        List<RuleAttrInfo> ruleAttrInfoList = ruleAttrResult.getData();
        List<RuleAttrCacheModel> attrCacheModelList = ruleAttrInfoList.stream()
                .map(RuleAttrCacheModel::ruleAttrBuild)
                .toList();
        return RuleCacheModel.builder()
                .ruleName(ruleInfo.getName())
                .ruleAttrModelList(attrCacheModelList)
                .build();
    }
}
