package com.muyu.product.remote;

import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.product.remote.factory.RemoteProjectSkuFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;

/**
 * @author DongZl
 * @description: 远程调用业务层
 * @Date 2024-4-7 上午 10:58
 */
@FeignClient(
        contextId = "remoteProjectSkuService",
        value = ServiceNameConstants.PRODUCT_SERVICE,
        fallbackFactory = RemoteProjectSkuFactory.class,
        path = "/sku"
)
public interface RemoteProjectSkuService {

    /**
     * 通过商品ID和SKU获取SKU信息
     * @param projectId 商品ID
     * @param projectSku 商品SKU
     * @return 商品SKU信息
     */
    @GetMapping("/info/{projectId}/{projectSku}")
    public Result<ProjectSkuInfo> getInfoByProjectIdAndSku(@PathVariable("projectId") Long projectId,
                                                           @PathVariable("projectSku") String projectSku);
    /**
     * 通过商品ID和SKU获取SKU信息
     * @param projectId 商品ID
     * @return 商品SKU信息
     */
    @GetMapping("/list/{projectId}")
    public Result<List<ProjectSkuInfo>> listByProjectId(@PathVariable("projectId") Long projectId);
}
