package com.muyu.product.remote.factory;

import com.muyu.common.core.domain.Result;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.product.remote.RemoteProjectSkuService;
import org.springframework.cloud.openfeign.FallbackFactory;

import java.util.List;

/**
 * @author DongZl
 * @description: 远程调熔断器
 * @Date 2024-4-7 上午 10:59
 */
public class RemoteProjectSkuFactory implements FallbackFactory<RemoteProjectSkuService> {
    @Override
    public RemoteProjectSkuService create (Throwable cause) {
        return new RemoteProjectSkuService() {
            @Override
            public Result<ProjectSkuInfo> getInfoByProjectIdAndSku (Long projectId, String projectSku) {
                return Result.error(cause.getMessage());
            }

            /**
             * 通过商品ID和SKU获取SKU信息
             *
             * @param projectId 商品ID
             *
             * @return 商品SKU信息
             */
            @Override
            public Result<List<ProjectSkuInfo>> listByProjectId (Long projectId) {
                return Result.error(cause.getMessage());
            }
        };
    }
}
