package com.muyu.product.cache.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.product.cache.datasource.ProjectSkuData;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.product.service.ProjectSkuInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author DongZl
 * @description: 商品SKU实现类
 * @Date 2024-4-1 上午 11:38
 */
@Service
@Primary
public class ProjectSkuDataImpl implements ProjectSkuData {

    @Autowired
    private ProjectSkuInfoService projectSkuInfoService;

    /**
     * 通过键获取所有的hash数据
     * @param projectId 商品ID
     * @return
     */
    @Override
    public Map<String, ProjectSkuInfo> getData (Long projectId) {
        LambdaQueryWrapper<ProjectSkuInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ProjectSkuInfo::getProjectId, projectId);
        List<ProjectSkuInfo> projectSkuInfoList = projectSkuInfoService.list(queryWrapper);
        return projectSkuInfoList.stream()
                .collect(Collectors.toMap(ProjectSkuInfo::getSku, projectSkuInfo -> projectSkuInfo));
    }

    /**
     * 通过缓存键和hash键获取hash值
     * @param projectId  商品ID
     * @param projectSku 商品SKU
     * @return hash值
     */
    @Override
    public ProjectSkuInfo getData (Long projectId, String projectSku) {
        LambdaQueryWrapper<ProjectSkuInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ProjectSkuInfo::getProjectId, projectId);
        queryWrapper.eq(ProjectSkuInfo::getSku, projectSku);
        return projectSkuInfoService.getOne(queryWrapper);
    }
}
