package com.muyu.product.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.CommentLikeInfo;
import com.muyu.product.domain.req.CommentLikeInfoQueryReq;
import com.muyu.product.domain.req.CommentLikeInfoSaveReq;
import com.muyu.product.domain.req.CommentLikeInfoEditReq;
import com.muyu.product.service.CommentLikeInfoService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 评论点赞Controller
 *
 * @author DongZeLiang
 * @date 2024-02-27
 */
@Api(tags = "评论点赞")
@RestController
@RequestMapping("/commentLike")
public class CommentLikeInfoController extends BaseController {
    @Autowired
    private CommentLikeInfoService commentLikeInfoService;

    /**
     * 查询评论点赞列表
     */
    @ApiOperation("获取评论点赞列表")
    @RequiresPermissions("product:commentLike:list")
    @GetMapping("/list")
    public Result<TableDataInfo<CommentLikeInfo>> list(CommentLikeInfoQueryReq commentLikeInfoQueryReq) {
        startPage();
        List<CommentLikeInfo> list = commentLikeInfoService.list(CommentLikeInfo.queryBuild(commentLikeInfoQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出评论点赞列表
     */
    @ApiOperation("导出评论点赞列表")
    @RequiresPermissions("product:commentLike:export")
    @Log(title = "评论点赞", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CommentLikeInfo commentLikeInfo) {
        List<CommentLikeInfo> list = commentLikeInfoService.list(commentLikeInfo);
        ExcelUtil<CommentLikeInfo> util = new ExcelUtil<CommentLikeInfo>(CommentLikeInfo.class);
        util.exportExcel(response, list, "评论点赞数据");
    }

    /**
     * 获取评论点赞详细信息
     */
    @ApiOperation("获取评论点赞详细信息")
    @RequiresPermissions("product:commentLike:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<CommentLikeInfo> getInfo(@PathVariable("id") Long id) {
        return Result.success(commentLikeInfoService.getById(id));
    }

    /**
     * 新增评论点赞
     */
    @RequiresPermissions("product:commentLike:add")
    @Log(title = "评论点赞", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增评论点赞")
    public Result<String> add(@RequestBody CommentLikeInfoSaveReq commentLikeInfoSaveReq) {
        return toAjax(commentLikeInfoService.save(CommentLikeInfo.saveBuild(commentLikeInfoSaveReq)));
    }

    /**
     * 修改评论点赞
     */
    @RequiresPermissions("product:commentLike:edit")
    @Log(title = "评论点赞", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改评论点赞")
    public Result<String> edit(@PathVariable Long id, @RequestBody CommentLikeInfoEditReq commentLikeInfoEditReq) {
        return toAjax(commentLikeInfoService.updateById(CommentLikeInfo.editBuild(id,commentLikeInfoEditReq)));
    }

    /**
     * 删除评论点赞
     */
    @RequiresPermissions("product:commentLike:remove")
    @Log(title = "评论点赞", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除评论点赞")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(commentLikeInfoService.removeBatchByIds(ids));
    }
}
