package com.muyu.shop.cart.cache;

import com.muyu.common.cache.abs.HashCacheAbs;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.common.core.text.Convert;
import com.muyu.shop.cart.cache.key.CartHashKey;
import com.muyu.shop.cart.cache.sourcedata.CartData;
import com.muyu.shop.cart.domain.CartInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @author DongZl
 * @description: 购物车缓存
 * @Date 2024-4-2 上午 11:23
 */
@Component
public class CartCache extends HashCacheAbs<Long, CartHashKey, CartInfo> {

    @Autowired
    private CartData cartData;

    /**
     * key前缀
     * @return key前缀
     */
    @Override
    public String keyPre () {
        return "cart:info:";
    }

    /**
     * 解码
     * @param redisKey 数据库键
     * @return ID
     */
    @Override
    public Long decode (String redisKey) {
        return Convert.toLong(redisKey.replace(keyPre(), ""));
    }

    /**
     * 编码
     *
     * @param hashKey ID
     *
     * @return 键
     */
    @Override
    public String encodeHashKey (CartHashKey hashKey) {
        return hashKey.getProjectId()+":"+hashKey.getProjectSku();
    }

    /**
     * 解码
     * @param redisHashKey 数据库键
     * @return ID
     */
    @Override
    public CartHashKey decodeHashKey (String redisHashKey) {
        String[] split = redisHashKey.split(":");
        return CartHashKey.builder()
                .projectId(Convert.toLong(split[0]))
                .projectSku(split[1])
                .build();
    }

    /**
     * 通过键获取所有的hash数据
     * @param key 键
     * @return
     */
    @Override
    public Map<CartHashKey, CartInfo> getData (Long key) {
        return cartData.getData(key);
    }

    /**
     * 通过缓存键和hash键获取hash值
     *
     * @param key     缓存键
     * @param hashKey hash键
     *
     * @return hash值
     */
    @Override
    public CartInfo getData (Long key, CartHashKey hashKey) {
        return cartData.getData(key, hashKey);
    }

    /**
     * 默认值
     */
    @Override
    public Map<CartHashKey, CartInfo> defaultValue () {
        throw new ServiceException("购物车无数据", Result.SUCCESS);
    }

    @Override
    public CartInfo defaultHashValue () {
        throw new ServiceException("购物车无数据", Result.SUCCESS);
    }

}
