package com.muyu.shop.cart.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.shop.cart.domain.req.CartInfoQueryReq;
import com.muyu.shop.cart.domain.req.CartInfoSaveReq;
import com.muyu.shop.cart.domain.req.CartInfoEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 购物车对象 cart_info
 *
 * @author DongZeLiang
 * @date 2024-03-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("cart_info")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "CartInfo", description = "购物车")
public class CartInfo extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 商品 */
    @Excel(name = "商品")
    @ApiModelProperty(name = "商品", value = "商品", required = true)
    private Long projectId;

    /** SKU */
    @Excel(name = "SKU")
    @ApiModelProperty(name = "SKU", value = "SKU", required = true)
    private String projectSku;

    /** 用户 */
    @Excel(name = "用户")
    @ApiModelProperty(name = "用户", value = "用户", required = true)
    private Long userId;

    /** 数量 */
    @Excel(name = "数量")
    @ApiModelProperty(name = "数量", value = "数量", required = true)
    private Long num;

    /** 是否选中 */
    @Excel(name = "是否选中")
    @ApiModelProperty(name = "是否选中", value = "是否选中", required = true)
    private String isSelected;

    /**
    * 查询构造器
    */
    public static CartInfo queryBuild( CartInfoQueryReq cartInfoQueryReq){
        return CartInfo.builder()
                .projectId(cartInfoQueryReq.getProjectId())
                .projectSku(cartInfoQueryReq.getProjectSku())
                .userId(cartInfoQueryReq.getUserId())
                .num(cartInfoQueryReq.getNum())
                .isSelected(cartInfoQueryReq.getIsSelected())
                .build();
    }

    /**
    * 添加构造器
    */
    public static CartInfo saveBuild(CartInfoSaveReq cartInfoSaveReq){
        return CartInfo.builder()
                .projectId(cartInfoSaveReq.getProjectId())
                .projectSku(cartInfoSaveReq.getProjectSku())
                .num(cartInfoSaveReq.getNum())
                .build();
    }

    /**
    * 修改构造器
    */
    public static CartInfo editBuild(Long id, CartInfoEditReq cartInfoEditReq){
        return CartInfo.builder()
            .id(id)
                .projectId(cartInfoEditReq.getProjectId())
                .projectSku(cartInfoEditReq.getProjectSku())
                .userId(cartInfoEditReq.getUserId())
                .num(cartInfoEditReq.getNum())
                .isSelected(cartInfoEditReq.getIsSelected())
                .build();
    }

}
