package com.muyu.shop.cart.service.sourcedata;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.shop.cart.cache.key.CartHashKey;
import com.muyu.shop.cart.cache.sourcedata.CartData;
import com.muyu.shop.cart.domain.CartInfo;
import com.muyu.shop.cart.service.CartInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author DongZl
 * @description: 缓存实现
 * @Date 2024-4-2 上午 11:51
 */

@Service
public class CartDataImpl implements CartData {

    @Autowired
    private CartInfoService cartInfoService;
    /**
     * 通过键获取所有的hash数据
     *
     * @param key 键
     *
     * @return
     */
    @Override
    public Map<CartHashKey, CartInfo> getData (Long key) {
        LambdaQueryWrapper<CartInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(CartInfo::getUserId, key);
        List<CartInfo> cartInfoList = cartInfoService.list(queryWrapper);
        return cartInfoList.stream()
                .collect(Collectors.toMap(cartInfo -> CartHashKey.builder().projectId(cartInfo.getProjectId()).projectSku(cartInfo.getProjectSku()).build(), cartInfo -> cartInfo));
    }

    /**
     * 通过缓存键和hash键获取hash值
     *
     * @param userId  缓存键
     * @param hashKey hash键
     *
     * @return hash值
     */
    @Override
    public CartInfo getData (Long userId, CartHashKey hashKey) {
        LambdaQueryWrapper<CartInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(CartInfo::getUserId, userId);
        queryWrapper.eq(CartInfo::getProjectId, hashKey.getProjectId());
        queryWrapper.eq(CartInfo::getProjectSku, hashKey.getProjectSku());
        return cartInfoService.getOne(queryWrapper);
    }
}
