package com.muyu.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.system.domain.SysDistrict;
import com.muyu.common.system.domain.req.SysDistrictEditReq;
import com.muyu.common.system.domain.req.SysDistrictQueryReq;
import com.muyu.common.system.domain.req.SysDistrictSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.system.service.SysDistrictService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 地域地区Controller
 *
 * @author DongZeLiang
 * @date 2024-04-11
 */
@Api(tags = "地域地区")
@RestController
@RequestMapping("/district")
public class SysDistrictController extends BaseController {
    @Autowired
    private SysDistrictService sysDistrictService;

    /**
     * 查询地域地区列表
     */
    @ApiOperation("获取地域地区列表")
    @RequiresPermissions("system:district:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysDistrict>> list(SysDistrictQueryReq sysDistrictQueryReq) {
        List<SysDistrict> list = sysDistrictService.list(SysDistrict.queryBuild(sysDistrictQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出地域地区列表
     */
    @ApiOperation("导出地域地区列表")
    @RequiresPermissions("system:district:export")
    @Log(title = "地域地区", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysDistrict sysDistrict) {
        List<SysDistrict> list = sysDistrictService.list(sysDistrict);
        ExcelUtil<SysDistrict> util = new ExcelUtil<SysDistrict>(SysDistrict.class);
        util.exportExcel(response, list, "地域地区数据");
    }

    /**
     * 获取地域地区详细信息
     */
    @ApiOperation("获取地域地区详细信息")
    @RequiresPermissions("system:district:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<SysDistrict> getInfo(@PathVariable("id") Long id) {
        return Result.success(sysDistrictService.getById(id));
    }

    /**
     * 新增地域地区
     */
    @RequiresPermissions("system:district:add")
    @Log(title = "地域地区", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增地域地区")
    public Result<String> add(@RequestBody SysDistrictSaveReq sysDistrictSaveReq) {
        return toAjax(sysDistrictService.save(SysDistrict.saveBuild(sysDistrictSaveReq)));
    }

    /**
     * 修改地域地区
     */
    @RequiresPermissions("system:district:edit")
    @Log(title = "地域地区", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改地域地区")
    public Result<String> edit(@PathVariable Long id, @RequestBody SysDistrictEditReq sysDistrictEditReq) {
        return toAjax(sysDistrictService.updateById(SysDistrict.editBuild(id,sysDistrictEditReq)));
    }

    /**
     * 删除地域地区
     */
    @RequiresPermissions("system:district:remove")
    @Log(title = "地域地区", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除地域地区")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(sysDistrictService.removeBatchByIds(ids));
    }
}
